"""
AvaTax Software Development Kit for Python.

   Copyright 2022 Avalara, Inc.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

    Avalara Shipping Verification only
    API for evaluating transactions against direct-to-consumer Beverage Alcohol shipping regulations.  This API is currently in beta.  

@author     Sachin Baijal <sachin.baijal@avalara.com>
@author     Jonathan Wenger <jonathan.wenger@avalara.com>
@copyright  2022 Avalara, Inc.
@license    https://www.apache.org/licenses/LICENSE-2.0
@version    2.4.5.4
@link       https://github.com/avadev/AvaTax-REST-V3-Python-SDK
"""

import re  # noqa: F401
import sys  # noqa: F401

from Avalara.SDK.api_client import ApiClient, Endpoint as _Endpoint
from Avalara.SDK.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from Avalara.SDK.model.error_details import ErrorDetails
from Avalara.SDK.model.shipping_verify_result import ShippingVerifyResult
from Avalara.SDK.exceptions import ApiTypeError, ApiValueError, ApiException

class ShippingVerificationApi(object):

    def __init__(self, api_client):
        self.__set_configuration(api_client)
    
    def __verify_api_client(self,api_client):
        if api_client is None:
            raise ApiValueError("APIClient not defined")
    
    def __set_configuration(self, api_client):
        self.__verify_api_client(api_client)
        api_client.set_sdk_version("2.4.5.4")
        self.api_client = api_client
		
        self.deregister_shipment_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'BasicAuth',
                    'Bearer'
                ],
                'endpoint_path': '/api/v2/companies/{companyCode}/transactions/{transactionCode}/shipment/registration',
                'operation_id': 'deregister_shipment',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'company_code',
                    'transaction_code',
                    'document_type',
                ],
                'required': [
                    'company_code',
                    'transaction_code',
                ],
                'nullable': [
                ],
                'enum': [
                    'document_type',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('document_type',): {

                        "SALESINVOICE": "SalesInvoice",
                        "RETURNINVOICE": "ReturnInvoice"
                    },
                },
                'openapi_types': {
                    'company_code':
                        (str,),
                    'transaction_code':
                        (str,),
                    'document_type':
                        (str,),
                },
                'attribute_map': {
                    'company_code': 'companyCode',
                    'transaction_code': 'transactionCode',
                    'document_type': 'documentType',
                },
                'location_map': {
                    'company_code': 'path',
                    'transaction_code': 'path',
                    'document_type': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.register_shipment_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'BasicAuth',
                    'Bearer'
                ],
                'endpoint_path': '/api/v2/companies/{companyCode}/transactions/{transactionCode}/shipment/registration',
                'operation_id': 'register_shipment',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'company_code',
                    'transaction_code',
                    'document_type',
                ],
                'required': [
                    'company_code',
                    'transaction_code',
                ],
                'nullable': [
                ],
                'enum': [
                    'document_type',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('document_type',): {

                        "SALESINVOICE": "SalesInvoice",
                        "RETURNINVOICE": "ReturnInvoice"
                    },
                },
                'openapi_types': {
                    'company_code':
                        (str,),
                    'transaction_code':
                        (str,),
                    'document_type':
                        (str,),
                },
                'attribute_map': {
                    'company_code': 'companyCode',
                    'transaction_code': 'transactionCode',
                    'document_type': 'documentType',
                },
                'location_map': {
                    'company_code': 'path',
                    'transaction_code': 'path',
                    'document_type': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.register_shipment_if_compliant_endpoint = _Endpoint(
            settings={
                'response_type': (ShippingVerifyResult,),
                'auth': [
                    'BasicAuth',
                    'Bearer'
                ],
                'endpoint_path': '/api/v2/companies/{companyCode}/transactions/{transactionCode}/shipment/registerIfCompliant',
                'operation_id': 'register_shipment_if_compliant',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'company_code',
                    'transaction_code',
                    'document_type',
                ],
                'required': [
                    'company_code',
                    'transaction_code',
                ],
                'nullable': [
                ],
                'enum': [
                    'document_type',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('document_type',): {

                        "SALESINVOICE": "SalesInvoice",
                        "RETURNINVOICE": "ReturnInvoice"
                    },
                },
                'openapi_types': {
                    'company_code':
                        (str,),
                    'transaction_code':
                        (str,),
                    'document_type':
                        (str,),
                },
                'attribute_map': {
                    'company_code': 'companyCode',
                    'transaction_code': 'transactionCode',
                    'document_type': 'documentType',
                },
                'location_map': {
                    'company_code': 'path',
                    'transaction_code': 'path',
                    'document_type': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.verify_shipment_endpoint = _Endpoint(
            settings={
                'response_type': (ShippingVerifyResult,),
                'auth': [
                    'BasicAuth',
                    'Bearer'
                ],
                'endpoint_path': '/api/v2/companies/{companyCode}/transactions/{transactionCode}/shipment/verify',
                'operation_id': 'verify_shipment',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'company_code',
                    'transaction_code',
                    'document_type',
                ],
                'required': [
                    'company_code',
                    'transaction_code',
                ],
                'nullable': [
                ],
                'enum': [
                    'document_type',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('document_type',): {

                        "SALESINVOICE": "SalesInvoice",
                        "RETURNINVOICE": "ReturnInvoice"
                    },
                },
                'openapi_types': {
                    'company_code':
                        (str,),
                    'transaction_code':
                        (str,),
                    'document_type':
                        (str,),
                },
                'attribute_map': {
                    'company_code': 'companyCode',
                    'transaction_code': 'transactionCode',
                    'document_type': 'documentType',
                },
                'location_map': {
                    'company_code': 'path',
                    'transaction_code': 'path',
                    'document_type': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def deregister_shipment(
        self,
        company_code,
        transaction_code,
        **kwargs
    ):
        """Removes the transaction from consideration when evaluating regulations that span multiple transactions.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.deregister_shipment(company_code, transaction_code, async_req=True)
        >>> result = thread.get()

        Args:
            company_code (str): The company code of the company that recorded the transaction
            transaction_code (str): The transaction code to retrieve

        Keyword Args:
            document_type (str): (Optional): The document type of the transaction to operate on. If omitted, defaults to \"SalesInvoice\". [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        self.__verify_api_client(self.api_client)
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['company_code'] = \
            company_code
        kwargs['transaction_code'] = \
            transaction_code
        return self.deregister_shipment_endpoint.call_with_http_info(**kwargs)

    def register_shipment(
        self,
        company_code,
        transaction_code,
        **kwargs
    ):
        """Registers the transaction so that it may be included when evaluating regulations that span multiple transactions.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.register_shipment(company_code, transaction_code, async_req=True)
        >>> result = thread.get()

        Args:
            company_code (str): The company code of the company that recorded the transaction
            transaction_code (str): The transaction code to retrieve

        Keyword Args:
            document_type (str): (Optional): The document type of the transaction to operate on. If omitted, defaults to \"SalesInvoice\". [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        self.__verify_api_client(self.api_client)
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['company_code'] = \
            company_code
        kwargs['transaction_code'] = \
            transaction_code
        return self.register_shipment_endpoint.call_with_http_info(**kwargs)

    def register_shipment_if_compliant(
        self,
        company_code,
        transaction_code,
        **kwargs
    ):
        """Evaluates a transaction against a set of direct-to-consumer shipping regulations and, if compliant, registers the transaction so that it may be included when evaluating regulations that span multiple transactions.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.register_shipment_if_compliant(company_code, transaction_code, async_req=True)
        >>> result = thread.get()

        Args:
            company_code (str): The company code of the company that recorded the transaction
            transaction_code (str): The transaction code to retrieve

        Keyword Args:
            document_type (str): (Optional): The document type of the transaction to operate on. If omitted, defaults to \"SalesInvoice\". [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ShippingVerifyResult
                If the method is called asynchronously, returns the request
                thread.
        """
        self.__verify_api_client(self.api_client)
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['company_code'] = \
            company_code
        kwargs['transaction_code'] = \
            transaction_code
        return self.register_shipment_if_compliant_endpoint.call_with_http_info(**kwargs)

    def verify_shipment(
        self,
        company_code,
        transaction_code,
        **kwargs
    ):
        """Evaluates a transaction against a set of direct-to-consumer shipping regulations.  # noqa: E501

        The transaction and its lines must meet the following criteria in order to be evaluated: * The transaction must be recorded. Using a type of *SalesInvoice* is recommended. * A parameter with the name *AlcoholRouteType* must be specified and the value must be one of the following: '*DTC*', '*Retailer DTC*' * A parameter with the name *RecipientName* must be specified and the value must be the name of the recipient. * Each alcohol line must include a *ContainerSize* parameter that describes the volume of a single container. Use the *unit* field to specify one of the following units: '*Litre*', '*Millilitre*', '*gallon (US fluid)*', '*quart (US fluid)*', '*ounce (fluid US customary)*' * Each alcohol line must include a *PackSize* parameter that describes the number of containers in a pack. Specify *Count* in the *unit* field.  Optionally, the transaction and its lines may use the following parameters: * The *ShipDate* parameter may be used if the date of shipment is different than the date of the transaction. The value should be ISO-8601 compliant (e.g. 2020-07-21). * The *RecipientDOB* parameter may be used to evaluate age restrictions. The value should be ISO-8601 compliant (e.g. 2020-07-21). * The *PurchaserDOB* parameter may be used to evaluate age restrictions. The value should be ISO-8601 compliant (e.g. 2020-07-21). * The *SalesLocation* parameter may be used to describe whether the sale was made *OnSite* or *OffSite*. *OffSite* is the default value. * The *AlcoholContent* parameter may be used to describe the alcohol percentage by volume of the item. Specify *Percentage* in the *unit* field.  **Security Policies** This API depends on all of the following active subscriptions: *AvaAlcohol, AutoAddress, AvaTaxPro*  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.verify_shipment(company_code, transaction_code, async_req=True)
        >>> result = thread.get()

        Args:
            company_code (str): The company code of the company that recorded the transaction
            transaction_code (str): The transaction code to retrieve

        Keyword Args:
            document_type (str): (Optional): The document type of the transaction to operate on. If omitted, defaults to \"SalesInvoice\". [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ShippingVerifyResult
                If the method is called asynchronously, returns the request
                thread.
        """
        self.__verify_api_client(self.api_client)
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['company_code'] = \
            company_code
        kwargs['transaction_code'] = \
            transaction_code
        return self.verify_shipment_endpoint.call_with_http_info(**kwargs)




import unittest
import pytest

import time
import Avalara.SDK
from Avalara.SDK.api.shipping_verification_api import ShippingVerificationApi  # noqa: E501

@pytest.mark.usefixtures("params")
class TestShippingVerificationApi(unittest.TestCase):
    """ShippingVerificationApi unit test stubs"""
    def setUp(self):
        configuration = Avalara.SDK.Configuration(
            username = self.params['username'], 
            password = self.params['password'],
            environment='sandbox'
        )
        with Avalara.SDK.ApiClient(configuration) as api_client:
            self.api = ShippingVerificationApi(api_client)

    def tearDown(self):
        pass

    def test_deregister_shipment(self):
        try:
            # self.api.deregister_shipment("Default","dededed")
            self.api.verify_shipment("DEFAULT", "063e1af4-11d3-4489-b8ba-ae1149758df4")
            print('Success')
        except Avalara.SDK.ApiException as e:
            print("Exception when calling ShippingVerification->verify_shipment: %s\n" % e)
            assert False

        print("Completed")
        pass

if __name__ == '__main__':
    unittest.main()


# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from Avalara.SDK.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from Avalara.SDK.model.age_verify_failure_code import AgeVerifyFailureCode
from Avalara.SDK.model.age_verify_request import AgeVerifyRequest
from Avalara.SDK.model.age_verify_request_address import AgeVerifyRequestAddress
from Avalara.SDK.model.age_verify_result import AgeVerifyResult
from Avalara.SDK.model.error_details import ErrorDetails
from Avalara.SDK.model.error_details_error import ErrorDetailsError
from Avalara.SDK.model.error_details_error_details import ErrorDetailsErrorDetails
from Avalara.SDK.model.shipping_verify_result import ShippingVerifyResult
from Avalara.SDK.model.shipping_verify_result_lines import ShippingVerifyResultLines



"""
AvaTax Software Development Kit for Python.

   Copyright 2022 Avalara, Inc.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

    Avalara Shipping Verification only
    API for evaluating transactions against direct-to-consumer Beverage Alcohol shipping regulations.  This API is currently in beta.  

@author     Sachin Baijal <sachin.baijal@avalara.com>
@author     Jonathan Wenger <jonathan.wenger@avalara.com>
@copyright  2022 Avalara, Inc.
@license    https://www.apache.org/licenses/LICENSE-2.0
@version    2.4.5.4
@link       https://github.com/avadev/AvaTax-REST-V3-Python-SDK
"""

import re  # noqa: F401
import sys  # noqa: F401

from Avalara.SDK.api_client import ApiClient, Endpoint as _Endpoint
from Avalara.SDK.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from Avalara.SDK.model.age_verify_failure_code import AgeVerifyFailureCode
from Avalara.SDK.model.age_verify_request import AgeVerifyRequest
from Avalara.SDK.model.age_verify_result import AgeVerifyResult
from Avalara.SDK.exceptions import ApiTypeError, ApiValueError, ApiException

class AgeVerificationApi(object):

    def __init__(self, api_client):
        self.__set_configuration(api_client)
    
    def __verify_api_client(self,api_client):
        if api_client is None:
            raise ApiValueError("APIClient not defined")
    
    def __set_configuration(self, api_client):
        self.__verify_api_client(api_client)
        api_client.set_sdk_version("2.4.5.4")
        self.api_client = api_client
		
        self.verify_age_endpoint = _Endpoint(
            settings={
                'response_type': (AgeVerifyResult,),
                'auth': [
                    'BasicAuth',
                    'Bearer'
                ],
                'endpoint_path': '/api/v2/ageverification/verify',
                'operation_id': 'verify_age',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'age_verify_request',
                    'simulated_failure_code',
                ],
                'required': [
                    'age_verify_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'age_verify_request':
                        (AgeVerifyRequest,),
                    'simulated_failure_code':
                        (AgeVerifyFailureCode,),
                },
                'attribute_map': {
                    'simulated_failure_code': 'simulatedFailureCode',
                },
                'location_map': {
                    'age_verify_request': 'body',
                    'simulated_failure_code': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def verify_age(
        self,
        age_verify_request,
        **kwargs
    ):
        """Determines whether an individual meets or exceeds the minimum legal drinking age.  # noqa: E501

        The request must meet the following criteria in order to be evaluated: * *firstName*, *lastName*, and *address* are required fields. * One of the following sets of attributes are required for the *address*:   * *line1, city, region*   * *line1, postalCode*  Optionally, the transaction and its lines may use the following parameters: * A *DOB* (Date of Birth) field. The value should be ISO-8601 compliant (e.g. 2020-07-21). * Beyond the required *address* fields above, a *country* field is permitted   * The valid values for this attribute are [*US, USA*]  **Security Policies** This API depends on the active subscription *AgeVerification*  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.verify_age(age_verify_request, async_req=True)
        >>> result = thread.get()

        Args:
            age_verify_request (AgeVerifyRequest): Information about the individual whose age is being verified.

        Keyword Args:
            simulated_failure_code (AgeVerifyFailureCode): (Optional) The failure code included in the simulated response of the endpoint. Note that this endpoint is only available in Sandbox for testing purposes.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            AgeVerifyResult
                If the method is called asynchronously, returns the request
                thread.
        """
        self.__verify_api_client(self.api_client)
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['age_verify_request'] = \
            age_verify_request
        return self.verify_age_endpoint.call_with_http_info(**kwargs)




"""
AvaTax Software Development Kit for Python.

   Copyright 2022 Avalara, Inc.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

    Avalara Shipping Verification for Beverage Alcohol
    API for evaluating transactions against direct-to-consumer Beverage Alcohol shipping regulations.  This API is currently in beta.  

@author     Sachin Baijal <sachin.baijal@avalara.com>
@author     Jonathan Wenger <jonathan.wenger@avalara.com>
@copyright  2022 Avalara, Inc.
@license    https://www.apache.org/licenses/LICENSE-2.0
@link       https://github.com/avadev/AvaTax-REST-V3-Python-SDK
"""


import unittest

import Avalara.SDK
from Avalara.SDK.api.shipping_verification_api import ShippingVerificationApi  # noqa: E501


class TestShippingVerificationApi(unittest.TestCase):
    """ShippingVerificationApi unit test stubs"""

    def setUp(self):
        """Test API stub"""
        # self.api = ShippingVerificationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_deregister_shipment(self):
        """Test case for deregister_shipment

        Removes the transaction from consideration when evaluating regulations that span multiple transactions.  # noqa: E501
        """
        pass

    def test_register_shipment(self):
        """Test case for register_shipment

        Registers the transaction so that it may be included when evaluating regulations that span multiple transactions.  # noqa: E501
        """
        pass

    def test_register_shipment_if_compliant(self):
        """Test case for register_shipment_if_compliant

        Evaluates a transaction against a set of direct-to-consumer shipping regulations and, if compliant, registers the transaction so that it may be included when evaluating regulations that span multiple transactions.  # noqa: E501
        """
        pass

    def test_verify_shipment(self):
        """Test case for verify_shipment

        Evaluates a transaction against a set of direct-to-consumer shipping regulations.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
AvaTax Software Development Kit for Python.

   Copyright 2022 Avalara, Inc.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

    Avalara Shipping Verification for Beverage Alcohol
    API for evaluating transactions against direct-to-consumer Beverage Alcohol shipping regulations.  This API is currently in beta.  

@author     Sachin Baijal <sachin.baijal@avalara.com>
@author     Jonathan Wenger <jonathan.wenger@avalara.com>
@copyright  2022 Avalara, Inc.
@license    https://www.apache.org/licenses/LICENSE-2.0
@link       https://github.com/avadev/AvaTax-REST-V3-Python-SDK
"""


import sys
import unittest

import Avalara.SDK
from Avalara.SDK.model.age_verify_request_address import AgeVerifyRequestAddress
globals()['AgeVerifyRequestAddress'] = AgeVerifyRequestAddress
from Avalara.SDK.model.age_verify_request import AgeVerifyRequest


class TestAgeVerifyRequest(unittest.TestCase):
    """AgeVerifyRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAgeVerifyRequest(self):
        """Test AgeVerifyRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AgeVerifyRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
